<?php

function bpca_admin_add() {

	$plugin_page = add_submenu_page ( 'bp-general-settings', __( 'Community Activate', 'bpca-community-activate' ), __( 'Community Activate', 'bpca-community-activate' ), 'manage_options', __FILE__, 'bpca_admin_panel' );

	add_action( "admin_print_scripts-$plugin_page", 'bpca_admin_scripts' );
	add_action( "admin_print_styles-$plugin_page", 'bpca_admin_styles' );
}
add_action( is_multisite() && function_exists( 'is_network_admin' ) ? 'network_admin_menu' : 'admin_menu', 'bpca_admin_add', 80 );

/* Stolen from Welcome Pack - thanks, Paul! */
function bpca_admin_add_action_link( $links, $file ) {
	if ( 'bp-community-activate/community-activate.php' != $file )
		return $links;

	$settings_link = '<a href="' . admin_url( 'admin.php?page=bp-community-activate/bp-community-activate-admin.php' ) . '">' . __( 'Settings', 'bpca-community-activate' ) . '</a>';
	array_unshift( $links, $settings_link );

	return $links;
}
add_filter( 'plugin_action_links', 'bpca_admin_add_action_link', 10, 2 );


function bpca_admin_scripts() {
	wp_enqueue_script( 'bpca-admin-js', WP_PLUGIN_URL . '/bp-community-activate/includes/js/admin-js.js' );
}

function bpca_admin_styles() {
	wp_enqueue_style( 'bpca-admin-css', WP_PLUGIN_URL . '/bp-community-activate/includes/css/admin.css' );
}

function bpca_admin_panel() {
	$subpage = isset( $_GET['subpage' ] ) ? $_GET['subpage'] : 'general-settings';

	// Get the proper URL for submitting the settings form. (Settings API workaround)
	$url_base = function_exists( 'is_network_admin' ) && is_network_admin() ? network_admin_url( 'admin.php?page=bp-community-activate/bp-community-activate-admin.php' ) : admin_url( 'admin.php?page=bp-community-activate/includes/bp-community-activate-admin.php' );

	$form_action = isset( $_GET['subpage'] ) ? add_query_arg( 'subpage', $_GET['subpage'], $url_base ) : $url_base;

	// Catch and save settings being saved (Settings API workaround)
	if ( !empty( $_POST['community-activate-settings-submit'] ) ) {

            //print_r ($_POST['bp_community_activate']); exit;

		$bpcaoptions        = get_option( 'bp_community_activate' );
		$_POST['bp_community_activate']['db_version']   = !empty( $bpcaoptions['db_version'] ) ? $bpcaoptions['db_version'] : BP_COMMUNITY_ACTIVATE_DBVERSION;
                $_POST['bp_community_activate']['version']      = !empty( $bpcaoptions['version'] ) ? $bpcaoptions['version'] : BP_COMMUNITY_ACTIVATE_VERSION;

		update_option( 'bp_community_activate', $_POST['bp_community_activate'] );
	}

?>
	<div class="wrap">
    	<h2><?php _e( 'Community Activate', 'bp-community-activate' ) ?></h2>

    	<ul class="ia-tabs">
    		<li<?php if ( 'general-settings' == $subpage ) : ?> class="current"<?php endif ?>>
    			<a href="<?php echo add_query_arg( 'subpage', 'general-settings', $url_base ) ?>"><?php _e( 'General Settings', 'bp-community-activate' ) ?></a>
    		</li>


    		<li<?php if ( 'stats' == $subpage ) : ?> class="current"<?php endif ?>>
    			<a href="<?php echo add_query_arg( 'subpage', 'recent_activations', $url_base ) ?>"><?php _e( 'Recent Activations', 'bp-community-activate' ) ?></a>
    		</li>


    	</ul>

    	<form action="<?php echo $form_action ?>" method="post">

	<?php /* The Settings API does not work with WP 3.1 Network Admin, but these functions still work to create the markup */ ?>
	<?php settings_fields( 'bp_community_activate' ); ?>
	<?php do_settings_sections( 'bp_community_activate' ); ?>

        <input id="community-activate-version" name="community-activate-version" value="<?php echo BP_COMMUNITY_ACTIVATE_VERSION; ?>" type="hidden" />

        <p>&nbsp;</p>

        <?php if ( 'general-settings' == $subpage ) : ?>
	<input id="community-activate-settings-submit" name="community-activate-settings-submit" type="submit" value="<?php esc_attr_e('Save Changes'); ?>" />
        <?php endif ?>
	</form>


    </div>
<?php
}


function bpca_settings_setup() {
	$subpage = isset( $_GET['subpage' ] ) ? $_GET['subpage'] : 'general-settings';

	register_setting( 'bp_community_activate', 'bp_community_activate', 'bpca_settings_check' );

	switch ( $subpage ) {

                case 'recent_activations' :
			add_settings_section('bpca_recent_activations', __('Recent Activations', 'bp-community-activate'), 'bpca_recent_activations_main_content', 'bp_community_activate');
                    
                break;

		case 'general-settings' :
		default :
			/* General Settings */
			add_settings_section('bpca_general_settings', __('General Settings', 'bp-community-activate'), 'bpca_settings_main_content', 'bp_community_activate');

			add_settings_field('bpca_settings_number_of_activations', __('Number of Activations Allowed Per User', 'bp-community-activate'), 'bpca_settings_number_of_activations', 'bp_community_activate', 'bpca_general_settings');

			add_settings_field('bpca_show_count_on_user_screen', __('Show activated count on user profile page', 'bp-community-activate'), 'bpca_show_count_on_user_screen', 'bp_community_activate', 'bpca_general_settings');

			add_settings_field('bpca_show_who_activated', __('Show "who-activated-me" data on user profile page', 'bp-community-activate'), 'bpca_show_who_activated', 'bp_community_activate', 'bpca_general_settings');

			add_settings_field('bpca_instructions_page_content', __('Customize the text users see when they get to the instructions page', 'bp-community-activate'), 'bpca_instructions_page_content', 'bp_community_activate', 'bpca_general_settings');


			break;
	}
}
add_action( 'admin_init', 'bpca_settings_setup' );


function bpca_recent_activations_main_content() {
    global $wpdb, $bp;

?>
	<p><?php _e( 'Top 100 Recent Activation Events:', 'bp-community-activate' ) ?></p>


<?php

        $activities = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM {$bp->activity->table_name} WHERE component = 'cactivate' AND type = 'activate_user' ORDER BY date_recorded DESC LIMIT 100" ) );

        if (sizeof($activities) > 0) {

?>
		<table class="widefat bp-stats">
			<thead><tr>
				<th scope="col" class="user-activated">
					<?php _e( 'User Activated', 'bp-community-activate' ) ?>
				</th>
				<th scope="col" class="who-activated">
					<?php _e( 'Who Activated Them', 'bp-community-activate' ) ?>
				</th>
				<th scope="col" class="when-activated">
					<?php _e( 'When', 'bp-community-activate' ) ?>
				</th>
                            </tr>
                        </thead>

			<tbody>
			<?php foreach( $activities as $activity ) :

                            $user_activated = new BP_Core_User($activity->item_id);
                            $who_activated = new BP_Core_User($activity->user_id);

                            //print_r ($activity);
                            
                            ?>
                            <tr>
                                <td><span style="float:left;"><?php echo $user_activated->avatar_mini; ?></span><a href="<?php echo $user_activated->user_url; ?>"><span style="float: left; line-height: 33px; padding: 0 0 0 10px;"><?php echo $user_activated->profile_data['Name']['field_data']; ?></span></a></td>
                                <td><span style="float:left;"><?php echo $who_activated->avatar_mini; ?></span><a href="<?php echo $who_activated->user_url; ?>"><span style="float: left; line-height: 33px; padding: 0 0 0 10px;"><?php echo $who_activated->profile_data['Name']['field_data']; ?></span></a></td>
                                <td><?php echo date('F jS, Y h:i a', strtotime($activity->date_recorded)); ?></td>
                            </tr>
                        <?php endforeach; ?>
                        </tbody>
                </table>

        <?

        } else { ?>

        <h4>Nothing To Report Yet</h4>

        <?php }

        

}



function bpca_settings_main_content() {
?>
	<p><?php _e( 'Control generally how the community activate functionality works, to tailor things to your needs.', 'bp-community-activate' ) ?></p>
<?php
}

function bpca_settings_number_of_activations() {
	$options = get_option( 'bp_community_activate' );
	echo "<input id='bpca_settings_number_of_activations' name='bp_community_activate[max_activations]' size='10' type='text' value='{$options['max_activations']}' />";
}

function bpca_show_count_on_user_screen() {
	$options = get_option( 'bp_community_activate' );
?>
	<input type="checkbox" name="bp_community_activate[show_count_on_user_screen]" value="yes" <?php checked( $options['show_count_on_user_screen'], 'yes' ) ?> />
<?php
}

function bpca_show_who_activated() {
	$options = get_option( 'bp_community_activate' );
?>
	<input type="checkbox" name="bp_community_activate[show_who_activated]" value="yes" <?php checked( $options['show_who_activated'], 'yes' ) ?> />

<?php
}

function bpca_instructions_page_content() {
	$options = get_option( 'bp_community_activate' );
?>
        <textarea style="width: 40%; height: 100px;" name="bp_community_activate[instructions_page_content]"><?php echo $options['instructions_page_content']; ?></textarea>
<?php
}

function bpca_settings_check($input) {
	return $input;
}

?>